@@ -25,7 +25,7 @@ class Storage(driver.Base):
         logger.info("==========================>jss_bucket:%s" % config.jss_bucket)
         logger.info("==========================>jss_domain:%s" % config.jss_domain)
         
-        self._jss = JssClient(self._access_key, self._secret_key, self._domain, "80")
+        self._jss = JssClient(self._access_key, self._secret_key, self._domain, None)
         
     def _init_path(self, path=None):
         if path:
@@ -85,18 +85,45 @@ class Storage(driver.Base):
         return path
 
 
+#    def stream_write(self, path, fp):
+#        logger.info("stream_write path:%s" % path)
+#        path1 = self._init_path(path)
+#        part_size = 5 * 1024 * 1024
+#        if self.buffer_size < part_size:
+#            part_size = self.buffer_size
+#        try:
+#             object_instance = self._jss.bucket(self._bucket).object(path1)
+#             object_instance.multi_upload_fp(None, fp, part_size)
+#        except Exception as e :
+#            logger.error("stream_write error:%s" % e)
+#            raise e
+
     def stream_write(self, path, fp):
         logger.info("stream_write path:%s" % path)
         path1 = self._init_path(path)
         part_size = 5 * 1024 * 1024
         if self.buffer_size < part_size:
             part_size = self.buffer_size
+        
         try:
-             object_instance = self._jss.bucket(self._bucket).object(path1)
-             object_instance.multi_upload_fp(None, None, fp, part_size)
+            tmp_file = tempfile.mktemp(suffix=path1, prefix=docker_registry_image, dir="/tmp")
+            with open(tmp_file, 'w') as f:
+                while True:
+                    buf = fp.read(part_size)
+                    if not buf: break
+                    f.write(buf)
+                
+            with open(tmp_file, 'r') as fp:
+                object_instance = self._jss.bucket(self._bucket).object(path1)
+                object_instance.multi_upload_fp(None, fp, part_size)
+                
         except Exception as e :
-            logger.error("stream_write error:%s" % e)
-            raise e
+             logger.error("stream_write error:%s" % e)
+             raise e
+        finally:
+            if os.path.exists(tmp_file):
+                os.remove(tmp_file)
+        
 
     @lru.remove
     def remove(self, path):
@@ -108,3 +135,16 @@ class Storage(driver.Base):
         except Exception as e:
             logger.error("remove error:%s" % e)
             raise e
+        
+    def exists(self, path):
+        logger.info("exists path:%s" % path)
+        path1 = self._init_path(path)
+        
+        try:
+            res = self._jss.bucket(self._bucket).get_key(path1)
+            if res is None :
+                return False
+            return True
+        except Exception as e:
+            
+            return False
